@@ -2,7 +2,6 @@
 """
 Advanced Stores for connecting to AWS data
 """
-
 import threading
 import warnings
 import zlib
@@ -37,13 +36,15 @@ class S3Store(Store):
         self,
         index: Store,
         bucket: str,
-        s3_profile: Union[str, dict] = None,
+        s3_profile: Optional[Union[str, dict]] = None,
         compress: bool = False,
         endpoint_url: str = None,
         sub_dir: str = None,
         s3_workers: int = 1,
+        s3_resource_kwargs: Optional[dict] = None,
         key: str = "fs_id",
         store_hash: bool = True,
+        unpack_data: bool = True,
         searchable_fields: Optional[List[str]] = None,
         **kwargs,
     ):
@@ -64,6 +65,7 @@ class S3Store(Store):
             sub_dir: (optional)  subdirectory of the s3 bucket to store the data
             s3_workers: number of concurrent S3 puts to run
             store_hash: store the sha1 hash right before insertion to the database.
+            unpack_data: whether to decompress and unpack byte data when querying from the bucket.
             searchable_fields: fields to keep in the index store
         """
         if boto3 is None:
@@ -78,7 +80,13 @@ class S3Store(Store):
         self.s3 = None  # type: Any
         self.s3_bucket = None  # type: Any
         self.s3_workers = s3_workers
-        self.searchable_fields = searchable_fields if searchable_fields else []
+        self.s3_resource_kwargs = (
+            s3_resource_kwargs if s3_resource_kwargs is not None else {}
+        )
+        self.unpack_data = unpack_data
+        self.searchable_fields = (
+            searchable_fields if searchable_fields is not None else []
+        )
         self.store_hash = store_hash
 
         # Force the key to be the same as the index
@@ -110,7 +118,9 @@ class S3Store(Store):
         """
 
         session = self._get_session()
-        resource = session.resource("s3", endpoint_url=self.endpoint_url)
+        resource = session.resource(
+            "s3", endpoint_url=self.endpoint_url, **self.s3_resource_kwargs
+        )
 
         if not self.s3:
             self.s3 = resource
@@ -170,6 +180,7 @@ class S3Store(Store):
                 values are 1 for ascending or -1 for descending.
             skip: number documents to skip
             limit: limit on total number of documents returned
+
         """
         prop_keys = set()
         if isinstance(properties, dict):
@@ -202,21 +213,30 @@ class S3Store(Store):
                     else:
                         raise e
 
-                if doc.get("compression", "") == "zlib":
-                    data = zlib.decompress(data)
-                # requires msgpack-python to be installed to fix string encoding problem
-                # https://github.com/msgpack/msgpack/issues/121
-                # During recursion
-                # msgpack.unpackb goes as deep as possible during reconstruction
-                # MontyDecoder().process_decode only goes until it finds a from_dict
-                # as such, we cannot just use msgpack.unpackb(data, object_hook=monty_object_hook, raw=False)
-                # Should just return the unpacked object then let the user run process_decoded
-                unpacked_data = msgpack.unpackb(data, raw=False)
-                if self.last_updated_field in doc:
-                    unpacked_data[self.last_updated_field] = doc[
-                        self.last_updated_field
-                    ]
-                yield unpacked_data
+                if self.unpack_data:
+                    data = self._unpack(
+                        data=data, compressed=doc.get("compression", "") == "zlib"
+                    )
+
+                    if self.last_updated_field in doc:
+                        data[self.last_updated_field] = doc[self.last_updated_field]
+
+                yield data
+
+    @staticmethod
+    def _unpack(data: bytes, compressed: bool):
+
+        if compressed:
+            data = zlib.decompress(data)
+        # requires msgpack-python to be installed to fix string encoding problem
+        # https://github.com/msgpack/msgpack/issues/121
+        # During recursion
+        # msgpack.unpackb goes as deep as possible during reconstruction
+        # MontyDecoder().process_decode only goes until it finds a from_dict
+        # as such, we cannot just use msgpack.unpackb(data, object_hook=monty_object_hook, raw=False)
+        # Should just return the unpacked object then let the user run process_decoded
+        unpacked_data = msgpack.unpackb(data, raw=False)
+        return unpacked_data
 
     def distinct(
         self, field: str, criteria: Optional[Dict] = None, all_exist: bool = False
@@ -417,7 +437,7 @@ class S3Store(Store):
         # Metadata stored in the MongoDB index (self.index) is stored unchanged.
 
         # Additionally, MinIO requires lowercase keys
-        return str(key).replace('_', '-').lower()
+        return str(key).replace("_", "-").lower()
 
     def remove_docs(self, criteria: Dict, remove_s3_object: bool = False):
         """
@@ -436,7 +456,7 @@ class S3Store(Store):
             # Can remove up to 1000 items at a time via boto
             to_remove_chunks = list(grouper(to_remove, n=1000))
             for chunk_to_remove in to_remove_chunks:
-                objlist = [{"Key": self.sub_dir + obj} for obj in chunk_to_remove]
+                objlist = [{"Key": f"{self.sub_dir}{obj}"} for obj in chunk_to_remove]
                 self.s3_bucket.delete_objects(Delete={"Objects": objlist})
 
     @property
